@@ -48,7 +48,7 @@ DFLT_OPTIONS = {
 
 pjoin = lambda *p: os.path.join(*p)
 DOCSRC = 'docsrc'
-DFLT_PUBLISH_DOCS_TO = None  #'github'
+DFLT_PUBLISH_DOCS_TO = None  # 'github'
 
 
 def git(command='status', work_tree='.', git_dir=None):
@@ -93,7 +93,7 @@ def clog(condition, *args, log_func=pprint, **kwargs):
 Path = str
 
 
-def check_in_changes(
+def check_in(
     commit_message: str,
     work_tree='.',
     git_dir=None,
@@ -107,19 +107,19 @@ def check_in_changes(
 
     :param commit_message: Your commit message
     :type commit_message: str
-    :param work_tree: The relative or absolute path of the working directory, defaults to '.'
+    :param work_tree: The relative or absolute path of the working directory. Defaults to '.'.
     :type work_tree: str, optional
-    :param git_dir: The relative or absolute path of the git directory, defaults to None
+    :param git_dir: The relative or absolute path of the git directory. If None, it will be taken to be "{work_tree}/.git/". Defaults to None.
     :type git_dir: str, optional
-    :param auto_choose_default_action: Set to True if you don't want to be prompted and automatically select the default action, defaults to False
+    :param auto_choose_default_action: Set to True if you don't want to be prompted and automatically select the default action. Defaults to False.
     :type auto_choose_default_action: bool, optional
-    :param bypass_docstring_validation: Set to True if you don't want to check if a docstring exist for every module, class and function, defaults to False
+    :param bypass_docstring_validation: Set to True if you don't want to check if a docstring exists for every module, class and function. Defaults to False.
     :type bypass_docstring_validation: bool, optional
-    :param bypass_tests: Set to True if you don't want to run doctests and other tests, defaults to False
+    :param bypass_tests: Set to True if you don't want to run doctests and other tests. Defaults to False.
     :type bypass_tests: bool, optional
-    :param bypass_code_formatting: Set to treu if you don;t want the code to be automatically formatted using axblack, defaults to False
+    :param bypass_code_formatting: Set to True if you don't want the code to be automatically formatted using axblack. Defaults to False.
     :type bypass_code_formatting: bool, optional
-    :param verbose: Set to True if you want to log extra information during the process, defaults to False
+    :param verbose: Set to True if you want to log extra information during the process. Defaults to False.
     :type verbose: bool, optional
     """
 
@@ -181,11 +181,6 @@ def check_in_changes(
                 for subdir in next(os.walk(current_dir))[1]:
                     run_pylint(os.path.join(current_dir, subdir))
 
-        print_step_title('Validate docstrings')
-        if not verbose:
-            pylint.lint.reporters.json_reporter.JSONReporter.display_messages = (
-                lambda self, layout: None
-            )
         run_pylint('.')
 
     def run_tests():
@@ -265,6 +260,48 @@ def check_in_changes(
     print('Your changes have been checked in successfully!')
 
 
+def goo(
+    pkg_dir,
+    commit_message,
+    git_dir=None,
+    auto_choose_default_action=False,
+    bypass_docstring_validation=False,
+    bypass_tests=False,
+    bypass_code_formatting=False,
+    verbose=False,
+):
+    """Validate, normalize, stage, commit and push your local changes to a remote repository.
+
+    :param pkg_dir: The relative or absolute path of the working directory. Defaults to '.'.
+    :type pkg_dir: str, optional
+    :param commit_message: Your commit message
+    :type commit_message: str
+    :param git_dir: The relative or absolute path of the git directory. If None, it will be taken to be "{work_tree}/.git/". Defaults to None.
+    :type git_dir: str, optional
+    :param auto_choose_default_action: Set to True if you don't want to be prompted and automatically select the default action. Defaults to False.
+    :type auto_choose_default_action: bool, optional
+    :param bypass_docstring_validation: Set to True if you don't want to check if a docstring exists for every module, class and function. Defaults to False.
+    :type bypass_docstring_validation: bool, optional
+    :param bypass_tests: Set to True if you don't want to run doctests and other tests. Defaults to False.
+    :type bypass_tests: bool, optional
+    :param bypass_code_formatting: Set to True if you don't want the code to be automatically formatted using axblack. Defaults to False.
+    :type bypass_code_formatting: bool, optional
+    :param verbose: Set to True if you want to log extra information during the process. Defaults to False.
+    :type verbose: bool, optional
+    """
+
+    return check_in(
+        commit_message=commit_message,
+        work_tree=pkg_dir,
+        git_dir=git_dir,
+        auto_choose_default_action=auto_choose_default_action,
+        bypass_docstring_validation=bypass_docstring_validation,
+        bypass_tests=bypass_tests,
+        bypass_code_formatting=bypass_code_formatting,
+        verbose=verbose,
+    )
+
+
 # TODO: Add a function that adds/commits/pushes the updated setup.cfg
 # TODO: Include tests as first step
 # TODO: blackify
@@ -276,6 +313,8 @@ def go(
     verbose: bool = True,
     skip_git_commit: bool = False,
     answer_yes_to_all_prompts: bool = False,
+    twine_upload_options_str: str = '',
+    keep_dist_pkgs=False,
 ):
     """Update version, package and deploy:
     Runs in a sequence: increment_configs_version, update_setup_cfg, run_setup, twine_upload_dist
@@ -290,8 +329,10 @@ def go(
     version = increment_configs_version(pkg_dir, version)
     update_setup_cfg(pkg_dir, verbose=verbose)
     run_setup(pkg_dir)
-    twine_upload_dist(pkg_dir)
-    delete_pkg_directories(pkg_dir, verbose)
+    twine_upload_dist(pkg_dir, twine_upload_options_str)
+
+    if not keep_dist_pkgs:
+        delete_pkg_directories(pkg_dir, verbose)
 
     if publish_docs_to:
         generate_and_publish_docs(pkg_dir, publish_docs_to)
@@ -404,7 +445,7 @@ def update_setup_cfg(pkg_dir, new_deploy=False, version=None, verbose=True):
     """
     pkg_dir = _get_pkg_dir(pkg_dir)
     configs = read_and_resolve_setup_configs(
-        pkg_dir=_get_pkg_dir(pkg_dir), new_deploy=new_deploy, version=version
+        pkg_dir=_get_pkg_dir(pkg_dir), new_deploy=new_deploy, version=version,
     )
     pprint('\n{configs}\n')
     clog(verbose, pprint(configs))
@@ -454,7 +495,7 @@ def run_setup(pkg_dir):
     # print(f"{setup_output}\n")
 
 
-def twine_upload_dist(pkg_dir):
+def twine_upload_dist(pkg_dir, options_str=None):
     """Publish to pypi. Runs ``python -m twine upload dist/*``"""
     print(
         '--------------------------- upload_output ---------------------------'
@@ -462,8 +503,13 @@ def twine_upload_dist(pkg_dir):
     pkg_dir = _get_pkg_dir(pkg_dir)
     original_dir = os.getcwd()
     os.chdir(pkg_dir)
-    # TODO: dist/*? How to publish just last on
-    subprocess.run(f'{sys.executable} -m twine upload dist/*'.split(' '))
+    # TODO: dist/*? How to publish just last one?
+    if options_str:
+        command = f'{sys.executable} -m twine upload {options_str} dist/*'
+    else:
+        command = f'{sys.executable} -m twine upload dist/*'
+    # print(command)
+    subprocess.run(command.split(' '))
     os.chdir(original_dir)
     # print(f"{upload_output.decode()}\n")
 
@@ -821,7 +867,8 @@ argh_kwargs = {
         read_and_resolve_setup_configs,
         update_setup_cfg,
         go,
-        check_in_changes,
+        goo,
+        check_in,
         get_name_from_configs,
         run_setup,
         current_pypi_version,
